<template>
  <AdminLayout>
    <DashboardHeader>
      <DashboardTitle>{{ $t("app.admin.settings.authentication.title") }}</DashboardTitle>
    </DashboardHeader>
    <SettingsBody>
      <template v-if="authenticationSettingsFetch.hasErrors">
        <ErrorState />
      </template>
      <template v-else>
        <FormGroup
          :is-loading="authenticationSettingsFetch.isFetching"
          @submit="submit"
        >
          <AlertError v-if="form.errors && form.errors?.unknown">
            {{ form.errors.unknown }}
          </AlertError>
          <FormSection>
            <FormInput
              id="register"
              :errors="form.errors.user_registration"
            >
              <FormSwitch
                v-model="form.values.user_registration"
                description="app.admin.settings.authentication.form.user_registration.description"
                label="app.admin.settings.authentication.form.user_registration.label"
              />
            </FormInput>
            <FormInput
              id="default_user_role_id"
              :errors="form.errors.default_user_role_id"
            >
              <FormLabel>{{ $t("app.admin.settings.authentication.form.default_user_role_id.label") }}</FormLabel>
              <UserRoleSelect v-model="form.values.default_user_role_id" />
              <FormHelp>{{ $t("app.admin.settings.authentication.form.default_user_role_id.description") }}</FormHelp>
            </FormInput>
          </FormSection>
          <div>
            <FormSubmit
              :processing="form.isFetching"
              class="btn btn-black"
            >
              {{ $t("app.admin.settings.submit") }}
            </FormSubmit>
          </div>
        </FormGroup>
      </template>
    </SettingsBody>
  </AdminLayout>
</template>

<script lang="ts" setup>
import DashboardHeader from "@/js/contexts/shared/ui/components/dashboard/DashboardHeader.vue";
import DashboardTitle from "@/js/contexts/shared/ui/components/dashboard/DashboardTitle.vue";
import AdminLayout from "@/js/contexts/admin/shared/ui/layouts/AdminLayout.vue";
import SettingsBody from "@/js/contexts/admin/settings/ui/components/SettingsBody.vue";
import AlertError from "@/js/contexts/shared/ui/components/alert/AlertError.vue";
import FormSection from "@/js/contexts/form/ui/components/FormSection.vue";
import FormSubmit from "@/js/contexts/form/ui/components/FormSubmit.vue";
import useForm from "@/js/contexts/shared/composables/useForm";
import FormGroup from "@/js/contexts/form/ui/components/FormGroup.vue";
import FormSwitch from "@/js/contexts/form/ui/components/FormSwitch.vue";
import FormLabel from "@/js/contexts/form/ui/components/FormLabel.vue";
import FormInput from "@/js/contexts/form/ui/components/FormInput.vue";
import UserRoleSelect from "@/js/contexts/admin/user-roles/ui/components/UserRoleSelect.vue";
import FormHelp from "@/js/contexts/form/ui/components/FormHelp.vue";
import useFetch from "@/js/contexts/shared/composables/useFetch";
import ErrorState from "@/js/contexts/shared/ui/components/error/ErrorState.vue";
import useNotification from "@/js/contexts/shared/composables/useNotification";

type Form = { user_registration: boolean; default_user_role_id: number | null };
type Response = { user_registration: boolean; default_user_role_id: number | null };

const { t } = useI18n();
const { successNotification } = useNotification();

useHead({
  title: t("app.admin.settings.authentication.title"),
});

const authenticationSettingsFetch = useFetch("/api/admin/settings/authentication", { isFetching: true });

const form = useForm<Form>({
  user_registration: false,
  default_user_role_id: null,
});

onMounted(() => {
  authenticationSettingsFetch.get<Response>().then((response) => {
    form.values.user_registration = response.data.user_registration;
    form.values.default_user_role_id = response.data.default_user_role_id;
    form.updatedValues();
  });
});

const submit = () => {
  form.post("/api/admin/settings/authentication", {
    onSuccess: () => successNotification(t("app.admin.settings.success")),
  });
};
</script>
